@@ -18,7 +18,7 @@ r'''Parse strings using a specification based on the Python format() syntax.
 The module is set up to only export ``parse()``, ``search()``, ``findall()``,
 and ``with_pattern()`` when ``import \*`` is used:
 
->>> from .parse import *
+>>> from parse import *
 
 From there it's a simple thing to parse a string:
 
@@ -48,7 +48,7 @@ compile it once:
 
 .. code-block:: pycon
 
-    >>> from .parse import compile
+    >>> from parse import compile
     >>> p = compile("It's {}, I love it!")
     >>> print(p)
     <Parser "It's {}, I love it!">
@@ -94,14 +94,14 @@ Some simple parse() format string examples:
     >>> r = parse("The {} who say {}", "The knights who say Ni!")
     >>> print(r)
     <Result ('knights', 'Ni!') {}>
-    >>> print((r.fixed))
+    >>> print(r.fixed)
     ('knights', 'Ni!')
     >>> r = parse("Bring out the holy {item}", "Bring out the holy hand grenade")
     >>> print(r)
     <Result () {'item': 'hand grenade'}>
-    >>> print((r.named))
+    >>> print(r.named)
     {'item': 'hand grenade'}
-    >>> print((r['item']))
+    >>> print(r['item'])
     hand grenade
     >>> 'item' in r
     True
@@ -114,16 +114,16 @@ are possible though the application must make additional sense of the result:
     >>> r = parse("Mmm, {food.type}, I love it!", "Mmm, spam, I love it!")
     >>> print(r)
     <Result () {'food.type': 'spam'}>
-    >>> print((r.named))
+    >>> print(r.named)
     {'food.type': 'spam'}
-    >>> print((r['food.type']))
+    >>> print(r['food.type'])
     spam
     >>> r = parse("My quest is {quest[name]}", "My quest is to seek the holy grail!")
     >>> print(r)
     <Result () {'quest': {'name': 'to seek the holy grail!'}}>
-    >>> print((r['quest']))
+    >>> print(r['quest'])
     {'name': 'to seek the holy grail!'}
-    >>> print((r['quest']['name']))
+    >>> print(r['quest']['name'])
     to seek the holy grail!
 
 If the text you're matching has braces in it you can match those by including
@@ -334,7 +334,7 @@ information to a type converter function:
 
 .. code-block:: pycon
 
-    >>> from .parse import with_pattern
+    >>> from parse import with_pattern
     >>> @with_pattern(r'\d+')
     ... def parse_number(text):
     ...    return int(text)
@@ -470,7 +470,7 @@ This code is copyright 2012-2020 Richard Jones <richard@python.org>
 See the end of the source file for the license of use.
 '''
 
-
+from __future__ import absolute_import
 
 __version__ = '1.18.0'
 
@@ -494,7 +494,7 @@ def with_pattern(pattern, regex_group_count=None):
     This annotates the type converter with the :attr:`pattern` attribute.
 
     EXAMPLE:
-        >>> from . import parse
+        >>> import parse
         >>> @parse.with_pattern(r"\d+")
         ... def parse_number(text):
         ...     return int(text)
@@ -943,7 +943,7 @@ class Parser(object):
 
     def _expand_named_fields(self, named_fields):
         result = {}
-        for field, value in list(named_fields.items()):
+        for field, value in named_fields.items():
             # split 'aaa[bbb][ccc]...' into 'aaa' and '[bbb][ccc]...'
             basename, subkeys = re.match(r'([^\[]+)(.*)', field).groups()
 
@@ -1492,4 +1492,3 @@ def compile(format, extra_types=None, case_sensitive=False):
 # SOFTWARE.
 
 # vim: set filetype=python ts=4 sw=4 et si tw=75
-
